@@ -67,7 +67,11 @@ class FrontendHighlighter(PygmentsHighlighter):
         # paragraph break characters, non-breaking spaces, etc. Here we acquire
         # the string as plain text so we can compare it.
         current_block = self.currentBlock()
-        string = self._frontend._get_block_plain_text(current_block)
+        string = current_block.text()
+
+        # QTextBlock::text() can still return non-breaking spaces
+        # for the continuation prompt
+        string = string.replace("\xa0", " ")
 
         # Only highlight if we can identify a prompt, but make sure not to
         # highlight the prompt.
@@ -729,7 +733,8 @@ class FrontendWidget(HistoryConsoleWidget, BaseFrontendMixin):
         """Clears the current line of output."""
         cursor = self._control.textCursor()
         cursor.beginEditBlock()
-        cursor.movePosition(cursor.StartOfLine, cursor.KeepAnchor)
+        cursor.movePosition(QtGui.QTextCursor.StartOfLine,
+                            QtGui.QTextCursor.KeepAnchor)
         cursor.insertText('')
         cursor.endEditBlock()
 
