@@ -6,13 +6,15 @@ import os
 import re
 from warnings import warn
 
-from qtconsole.qt import QtCore, QtGui
+from qtpy import QtCore, QtGui, QtWidgets
 
 from ipython_genutils.path import ensure_dir_exists
 from traitlets import Bool
+from pygments.util import ClassNotFound
+
 from qtconsole.svg import save_svg, svg_to_clipboard, svg_to_image
 from .jupyter_widget import JupyterWidget
-
+from .styles import get_colors
 
 try:
     from IPython.lib.latextools import latex_to_png
@@ -50,7 +52,7 @@ class RichJupyterWidget(RichIPythonWidget):
         """ Create a RichJupyterWidget.
         """
         kw['kind'] = 'rich'
-        super(RichJupyterWidget, self).__init__(*args, **kw)
+        super().__init__(*args, **kw)
 
         # Configure the ConsoleWidget HTML exporter for our formats.
         self._html_exporter.image_tag = self._get_image_tag
@@ -75,7 +77,7 @@ class RichJupyterWidget(RichIPythonWidget):
         to the export running.
         """
         self._svg_warning_displayed = False
-        super(RichJupyterWidget, self).export_html()
+        super().export_html()
 
 
     #---------------------------------------------------------------------------
@@ -88,7 +90,7 @@ class RichJupyterWidget(RichIPythonWidget):
         format = self._control.cursorForPosition(pos).charFormat()
         name = format.stringProperty(QtGui.QTextFormat.ImageName)
         if name:
-            menu = QtGui.QMenu(self)
+            menu = QtWidgets.QMenu(self)
 
             menu.addAction('Copy Image', lambda: self._copy_image(name))
             menu.addAction('Save Image As...', lambda: self._save_image(name))
@@ -101,7 +103,7 @@ class RichJupyterWidget(RichIPythonWidget):
                 menu.addAction('Save SVG As...',
                                lambda: save_svg(svg, self._control))
         else:
-            menu = super(RichJupyterWidget, self)._context_menu_make(pos)
+            menu = super()._context_menu_make(pos)
         return menu
 
     #---------------------------------------------------------------------------
@@ -146,11 +148,11 @@ class RichJupyterWidget(RichIPythonWidget):
                 try:
                     self._append_latex(data['text/latex'], True)
                 except LatexError:
-                    return super(RichJupyterWidget, self)._handle_display_data(msg)
+                    return super()._handle_display_data(msg)
                 self._append_html(self.output_sep2, True)
             else:
                 # Default back to the plain text representation.
-                return super(RichJupyterWidget, self)._handle_execute_result(msg)
+                return super()._handle_execute_result(msg)
 
     def _handle_display_data(self, msg):
         """Overridden to handle rich data types, like SVG."""
@@ -177,10 +179,10 @@ class RichJupyterWidget(RichIPythonWidget):
                 try:
                     self._append_latex(data['text/latex'], True)
                 except LatexError:
-                    return super(RichJupyterWidget, self)._handle_display_data(msg)
+                    return super()._handle_display_data(msg)
             else:
                 # Default back to the plain text representation.
-                return super(RichJupyterWidget, self)._handle_display_data(msg)
+                return super()._handle_display_data(msg)
 
     #---------------------------------------------------------------------------
     # 'RichJupyterWidget' protected interface
@@ -212,19 +214,30 @@ class RichJupyterWidget(RichIPythonWidget):
                 return True
         return False
 
+    def _get_color(self, color):
+        """Get color from the current syntax style if loadable."""
+        try:
+            return get_colors(self.syntax_style)[color]
+        except ClassNotFound:
+            # The syntax_style has been sideloaded (e.g. by spyder).
+            # In this case the overloading class should override this method.
+            return get_colors('default')[color]
+
     def _append_latex(self, latex, before_prompt=False, metadata=None):
         """ Append latex data to the widget."""
         png = None
 
         if self._is_latex_math(latex):
-            png = latex_to_png(latex, wrap=False, backend='dvipng')
+            png = latex_to_png(latex, wrap=False, backend='dvipng',
+                               color=self._get_color('fgcolor'))
 
         # Matplotlib only supports strings enclosed in dollar signs
         if png is None and latex.startswith('$') and latex.endswith('$'):
             # To avoid long and ugly errors, like the one reported in
             # spyder-ide/spyder#7619
             try:
-                png = latex_to_png(latex, wrap=False, backend='matplotlib')
+                png = latex_to_png(latex, wrap=False, backend='matplotlib',
+                                   color=self._get_color('fgcolor'))
             except Exception:
                 pass
 
@@ -263,7 +276,7 @@ class RichJupyterWidget(RichIPythonWidget):
         """ Copies the ImageResource with 'name' to the clipboard.
         """
         image = self._get_image(name)
-        QtGui.QApplication.clipboard().setImage(image)
+        QtWidgets.QApplication.clipboard().setImage(image)
 
     def _get_image(self, name):
         """ Returns the QImage stored as the ImageResource with 'name'.
@@ -319,13 +332,13 @@ class RichJupyterWidget(RichIPythonWidget):
                 svg = str(self._name_to_svg_map[match.group("name")])
             except KeyError:
                 if not self._svg_warning_displayed:
-                    QtGui.QMessageBox.warning(self, 'Error converting PNG to SVG.',
+                    QtWidgets.QMessageBox.warning(self, 'Error converting PNG to SVG.',
                         'Cannot convert PNG images to SVG, export with PNG figures instead. '
                         'If you want to export matplotlib figures as SVG, add '
                         'to your ipython config:\n\n'
                         '\tc.InlineBackend.figure_format = \'svg\'\n\n'
                         'And regenerate the figures.',
-                                              QtGui.QMessageBox.Ok)
+                                              QtWidgets.QMessageBox.Ok)
                     self._svg_warning_displayed = True
                 return ("<b>Cannot convert  PNG images to SVG.</b>  "
                         "You must export this session with PNG images. "
@@ -398,8 +411,8 @@ class RichJupyterWidget(RichIPythonWidget):
     def _save_image(self, name, format='PNG'):
         """ Shows a save dialog for the ImageResource with 'name'.
         """
-        dialog = QtGui.QFileDialog(self._control, 'Save Image')
-        dialog.setAcceptMode(QtGui.QFileDialog.AcceptSave)
+        dialog = QtWidgets.QFileDialog(self._control, 'Save Image')
+        dialog.setAcceptMode(QtWidgets.QFileDialog.AcceptSave)
         dialog.setDefaultSuffix(format.lower())
         dialog.setNameFilter('%s file (*.%s)' % (format, format.lower()))
         if dialog.exec_():
@@ -415,4 +428,4 @@ class RichIPythonWidget(RichJupyterWidget):
     def __init__(self, *a, **kw):
         warn("RichIPythonWidget is deprecated, use RichJupyterWidget",
              DeprecationWarning)
-        super(RichIPythonWidget, self).__init__(*a, **kw)
+        super().__init__(*a, **kw)
